@@ -1,5 +1,5 @@
 /* info-utils.c -- miscellanous.
-   $Id: info-utils.c 7254 2016-07-10 19:24:14Z gavin $
+   $Id: info-utils.c 7332 2016-09-03 16:20:45Z gavin $
 
    Copyright 1993, 1998, 2003, 2004, 2007, 2008, 2009, 2011, 2012,
    2013, 2014, 2015 Free Software Foundation, Inc.
@@ -1495,14 +1495,6 @@ scan_reference_target (REFERENCE *entry, NODE *node, int in_parentheses)
         else
           entry->line_number = 0;
       }
-
-      if (preprocess_nodes_p && entry->line_number > 1)
-        /* Adjust line offset in file to one in displayed text.  This
-           does not work perfectly because we can't know exactly what
-           text will be inserted/removed: for example, due to expansion
-           of an image tag.  This subtracts 1 for a removed node information
-           line. */
-        entry->line_number--;
     }
 
   return 1;
