@@ -1,20 +1,14 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'not_set'} = {
-  'contents' => [
-    {
-      'parent' => {},
-      'type' => 'before_node_section'
-    }
-  ],
-  'type' => 'document_root'
+  'contents' => [],
+  'type' => 'text_root'
 };
-$result_trees{'not_set'}{'contents'}[0]{'parent'} = $result_trees{'not_set'};
 
 $result_texis{'not_set'} = '';
 
@@ -24,7 +18,4 @@ $result_texts{'not_set'} = '';
 $result_errors{'not_set'} = [];
 
 
-$result_floats{'not_set'} = {};
-
-
 1;
