@@ -153,23 +153,34 @@ $result_trees{'no_documentencoding_and_insertions'} = {
           'args' => [
             {
               'contents' => [
+                {
+                  'extra' => {
+                    'command' => {}
+                  },
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_after_command'
+                },
                 {
                   'parent' => {},
                   'text' => 'example'
+                },
+                {
+                  'parent' => {},
+                  'text' => '
+',
+                  'type' => 'spaces_at_end'
                 }
               ],
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
               'parent' => {},
-              'type' => 'line_arg'
+              'type' => 'misc_line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
+            'command' => {},
             'command_argument' => 'example',
-            'spaces_before_argument' => ' ',
+            'spaces_after_command' => {},
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -181,7 +192,8 @@ $result_trees{'no_documentencoding_and_insertions'} = {
         }
       ],
       'extra' => {
-        'end_command' => {}
+        'end_command' => {},
+        'spaces_after_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -219,10 +231,16 @@ $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'extra'}{'command'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[2];
+$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[0];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'parent'} = $result_trees{'no_documentencoding_and_insertions'};
 
 $result_texis{'no_documentencoding_and_insertions'} = '
@@ -244,9 +262,9 @@ $result_errors{'no_documentencoding_and_insertions'} = [];
 
 
 
-$result_converted{'plaintext'}->{'no_documentencoding_and_insertions'} = '- -- " " \' \' \'in code\'.  ẽ.
+$result_converted{'plaintext'}->{'no_documentencoding_and_insertions'} = '- -- " " \' \' \'in code\'.  e~.
 
-     -- --- \'\' `` ` \' in code. ẽ.
+     -- --- \'\' `` ` \' in code. e~.
 ';
 
 
