@@ -1,31 +1,42 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'float_long_captions'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => ' ',
+              'type' => 'empty_spaces_after_command'
+            },
             {
               'parent' => {},
               'text' => 'Top'
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'spaces_at_end'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
-'
-          },
           'parent' => {},
-          'type' => 'line_arg'
+          'type' => 'misc_line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -40,6 +51,14 @@ $result_trees{'float_long_captions'} = {
           'args' => [
             {
               'contents' => [
+                {
+                  'extra' => {
+                    'command' => {}
+                  },
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_after_command'
+                },
                 {
                   'parent' => {},
                   'text' => 'Text'
@@ -50,16 +69,22 @@ $result_trees{'float_long_captions'} = {
             },
             {
               'contents' => [
+                {
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_before_argument'
+                },
                 {
                   'parent' => {},
                   'text' => 'text1'
+                },
+                {
+                  'parent' => {},
+                  'text' => '
+',
+                  'type' => 'space_at_end_block_command'
                 }
               ],
-              'extra' => {
-                'spaces_after_argument' => '
-',
-                'spaces_before_argument' => ' '
-              },
               'parent' => {},
               'type' => 'block_line_arg'
             }
@@ -86,15 +111,16 @@ $result_trees{'float_long_captions'} = {
                 }
               ],
               'cmdname' => 'caption',
+              'contents' => [],
               'extra' => {
                 'float' => {}
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 4,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -105,39 +131,60 @@ $result_trees{'float_long_captions'} = {
               'args' => [
                 {
                   'contents' => [
+                    {
+                      'extra' => {
+                        'command' => {}
+                      },
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_after_command'
+                    },
                     {
                       'parent' => {},
                       'text' => 'float'
+                    },
+                    {
+                      'parent' => {},
+                      'text' => '
+',
+                      'type' => 'spaces_at_end'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'type' => 'misc_line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
+                'command' => {},
+                'command_argument' => 'float',
+                'spaces_after_command' => {},
                 'text_arg' => 'float'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'extra' => {
+            'block_command_line_contents' => [
+              [
+                {}
+              ],
+              [
+                {}
+              ]
+            ],
             'caption' => {},
+            'end_command' => {},
             'node_content' => [
               {}
             ],
             'normalized' => 'text1',
-            'spaces_before_argument' => ' ',
+            'spaces_after_command' => {},
             'type' => {
               'content' => [
                 {}
@@ -145,12 +192,13 @@ $result_trees{'float_long_captions'} = {
               'normalized' => 'Text'
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
             'macro' => ''
-          }
+          },
+          'number' => 1,
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -162,6 +210,14 @@ $result_trees{'float_long_captions'} = {
           'args' => [
             {
               'contents' => [
+                {
+                  'extra' => {
+                    'command' => {}
+                  },
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_after_command'
+                },
                 {
                   'parent' => {},
                   'text' => 'Text'
@@ -172,16 +228,22 @@ $result_trees{'float_long_captions'} = {
             },
             {
               'contents' => [
+                {
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_before_argument'
+                },
                 {
                   'parent' => {},
                   'text' => 'text2'
+                },
+                {
+                  'parent' => {},
+                  'text' => '
+',
+                  'type' => 'space_at_end_block_command'
                 }
               ],
-              'extra' => {
-                'spaces_after_argument' => '
-',
-                'spaces_before_argument' => ' '
-              },
               'parent' => {},
               'type' => 'block_line_arg'
             }
@@ -208,15 +270,16 @@ $result_trees{'float_long_captions'} = {
                 }
               ],
               'cmdname' => 'caption',
+              'contents' => [],
               'extra' => {
                 'float' => {}
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 8,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -227,39 +290,60 @@ $result_trees{'float_long_captions'} = {
               'args' => [
                 {
                   'contents' => [
+                    {
+                      'extra' => {
+                        'command' => {}
+                      },
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_after_command'
+                    },
                     {
                       'parent' => {},
                       'text' => 'float'
+                    },
+                    {
+                      'parent' => {},
+                      'text' => '
+',
+                      'type' => 'spaces_at_end'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'type' => 'misc_line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
+                'command' => {},
+                'command_argument' => 'float',
+                'spaces_after_command' => {},
                 'text_arg' => 'float'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 9,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'extra' => {
+            'block_command_line_contents' => [
+              [
+                {}
+              ],
+              [
+                {}
+              ]
+            ],
             'caption' => {},
+            'end_command' => {},
             'node_content' => [
               {}
             ],
             'normalized' => 'text2',
-            'spaces_before_argument' => ' ',
+            'spaces_after_command' => {},
             'type' => {
               'content' => [
                 {}
@@ -267,12 +351,13 @@ $result_trees{'float_long_captions'} = {
               'normalized' => 'Text'
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 7,
             'macro' => ''
-          }
+          },
+          'number' => 2,
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -284,22 +369,32 @@ $result_trees{'float_long_captions'} = {
           'args' => [
             {
               'contents' => [
+                {
+                  'extra' => {
+                    'command' => {}
+                  },
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_after_command'
+                },
                 {
                   'parent' => {},
                   'text' => 'Text'
+                },
+                {
+                  'parent' => {},
+                  'text' => '
+',
+                  'type' => 'spaces_at_end'
                 }
               ],
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
               'parent' => {},
-              'type' => 'line_arg'
+              'type' => 'misc_line_arg'
             }
           ],
           'cmdname' => 'listoffloats',
           'extra' => {
-            'spaces_before_argument' => ' ',
+            'spaces_after_command' => {},
             'type' => {
               'content' => [
                 {}
@@ -307,12 +402,12 @@ $result_trees{'float_long_captions'} = {
               'normalized' => 'Text'
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 11,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
@@ -321,32 +416,37 @@ $result_trees{'float_long_captions'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [
-              {}
-            ],
+            'node_content' => [],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_before_argument' => ' '
+        'spaces_after_command' => {}
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
 $result_trees{'float_long_captions'}{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'};
+$result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0];
@@ -354,17 +454,30 @@ $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'float'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'block_command_line_contents'}[1][0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'caption'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
-$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'args'}[0];
@@ -372,20 +485,34 @@ $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'extra'}{'float'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'block_command_line_contents'}[1][0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'caption'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[0];
-$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[0];
-$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5];
-$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'extra'}{'type'}{'content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[1];
 $result_trees{'float_long_captions'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'float_long_captions'}{'contents'}[1];
-$result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'float_long_captions'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'float_long_captions'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'float_long_captions'}{'contents'}[1]{'parent'} = $result_trees{'float_long_captions'};
 
 $result_texis{'float_long_captions'} = '@node Top
@@ -411,12 +538,26 @@ Text, text2
 
 ';
 
+$result_sectioning{'float_long_captions'} = {};
+
 $result_nodes{'float_long_captions'} = {
   'cmdname' => 'node',
   'extra' => {
     'normalized' => 'Top'
+  },
+  'node_up' => {
+    'extra' => {
+      'manual_content' => [
+        {
+          'text' => 'dir'
+        }
+      ],
+      'top_node_up' => {}
+    },
+    'type' => 'top_node_up'
   }
 };
+$result_nodes{'float_long_captions'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'float_long_captions'};
 
 $result_menus{'float_long_captions'} = {
   'cmdname' => 'node',
@@ -439,6 +580,14 @@ $result_floats{'float_long_captions'} = {
             'float' => {}
           }
         },
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command' => {},
+            'command_argument' => 'float',
+            'text_arg' => 'float'
+          }
+        },
         'normalized' => 'text1',
         'type' => {
           'content' => [
@@ -449,9 +598,7 @@ $result_floats{'float_long_captions'} = {
           'normalized' => 'Text'
         }
       },
-      'structure' => {
-        'float_number' => 1
-      }
+      'number' => 1
     },
     {
       'cmdname' => 'float',
@@ -462,6 +609,14 @@ $result_floats{'float_long_captions'} = {
             'float' => {}
           }
         },
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command' => {},
+            'command_argument' => 'float',
+            'text_arg' => 'float'
+          }
+        },
         'normalized' => 'text2',
         'type' => {
           'content' => [
@@ -472,14 +627,14 @@ $result_floats{'float_long_captions'} = {
           'normalized' => 'Text'
         }
       },
-      'structure' => {
-        'float_number' => 2
-      }
+      'number' => 2
     }
   ]
 };
 $result_floats{'float_long_captions'}{'Text'}[0]{'extra'}{'caption'}{'extra'}{'float'} = $result_floats{'float_long_captions'}{'Text'}[0];
+$result_floats{'float_long_captions'}{'Text'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_floats{'float_long_captions'}{'Text'}[0];
 $result_floats{'float_long_captions'}{'Text'}[1]{'extra'}{'caption'}{'extra'}{'float'} = $result_floats{'float_long_captions'}{'Text'}[1];
+$result_floats{'float_long_captions'}{'Text'}[1]{'extra'}{'end_command'}{'extra'}{'command'} = $result_floats{'float_long_captions'}{'Text'}[1];
 
 
 
@@ -488,10 +643,8 @@ $result_converted{'info'}->{'float_long_captions'} = 'This is , produced from .
 
 File: ,  Node: Top,  Up: (dir)
 
-
 Text 1: AAAAAAAAAAAAAAAA BBBBB CCCCCCCCCCC
 
-
 Text 2: AAAAAAAAAAAAAAAA BBBBBB CCCCCCCCCCC
 
 * Menu:
@@ -504,14 +657,9 @@ Text 2: AAAAAAAAAAAAAAAA BBBBBB CCCCCCCCCCC
 Tag Table:
 Node: Top27
 Ref: text161
-Ref: text2106
+Ref: text2105
 
 End Tag Table
-
-
-Local Variables:
-coding: utf-8
-End:
 ';
 
 1;
