@@ -1,20 +1,29 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'on_node_line'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => ' ',
+              'type' => 'empty_spaces_after_command'
+            },
             {
               'args' => [
                 {
@@ -29,65 +38,93 @@ $result_trees{'on_node_line'} = {
                 },
                 {
                   'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_before_argument'
+                    },
                     {
                       'parent' => {},
                       'text' => 'b'
                     }
                   ],
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 },
                 {
                   'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_before_argument'
+                    },
                     {
                       'parent' => {},
                       'text' => 'c'
                     }
                   ],
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 },
                 {
                   'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_before_argument'
+                    },
                     {
                       'parent' => {},
                       'text' => 'filename'
                     }
                   ],
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'ref',
+              'contents' => [],
               'extra' => {
+                'brace_command_contents' => [
+                  [
+                    {}
+                  ],
+                  [
+                    {}
+                  ],
+                  [
+                    {}
+                  ],
+                  [
+                    {}
+                  ]
+                ],
+                'invalid_nesting' => 1,
                 'node_argument' => {
                   'node_content' => [
                     {}
-                  ]
+                  ],
+                  'normalized' => 'a'
                 }
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'parent' => {},
-          'type' => 'line_arg'
+          'type' => 'misc_line_arg'
         },
         {
           'contents' => [
+            {
+              'parent' => {},
+              'text' => ' ',
+              'type' => 'empty_spaces_before_argument'
+            },
             {
               'parent' => {},
               'text' => '('
@@ -98,19 +135,7 @@ $result_trees{'on_node_line'} = {
                   'contents' => [
                     {
                       'parent' => {},
-                      'text' => '('
-                    },
-                    {
-                      'parent' => {},
-                      'text' => 'somemanual'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => ')'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => 'Top'
+                      'text' => '(somemanual)Top'
                     }
                   ],
                   'parent' => {},
@@ -118,30 +143,36 @@ $result_trees{'on_node_line'} = {
                 }
               ],
               'cmdname' => 'pxref',
+              'contents' => [],
               'extra' => {
-                'node_argument' => {
-                  'manual_content' => [
-                    {}
-                  ],
-                  'node_content' => [
+                'brace_command_contents' => [
+                  [
                     {}
                   ]
+                ],
+                'invalid_nesting' => 1,
+                'node_argument' => {
+                  'manual_content' => [
+                    {
+                      'parent' => {},
+                      'text' => 'somemanual'
+                    }
+                  ],
+                  'node_content' => [
+                    {
+                      'parent' => {},
+                      'text' => 'Top'
+                    }
+                  ],
+                  'normalized' => 'Top'
                 }
               },
-              'parent' => {},
-              'source_info' => {
-                'file_name' => '',
-                'line_nr' => 1,
-                'macro' => ''
-              }
+              'line_nr' => {},
+              'parent' => {}
             },
             {
               'parent' => {},
-              'text' => ')'
-            },
-            {
-              'parent' => {},
-              'text' => ' '
+              'text' => ') '
             },
             {
               'args' => [
@@ -157,18 +188,21 @@ $result_trees{'on_node_line'} = {
                 }
               ],
               'cmdname' => 'anchor',
+              'contents' => [],
               'extra' => {
+                'brace_command_contents' => [
+                  [
+                    {}
+                  ]
+                ],
+                'invalid_nesting' => 1,
                 'node_content' => [
                   {}
                 ],
                 'normalized' => 'in-anchor'
               },
-              'parent' => {},
-              'source_info' => {
-                'file_name' => '',
-                'line_nr' => 1,
-                'macro' => ''
-              }
+              'line_nr' => {},
+              'parent' => {}
             },
             {
               'args' => [
@@ -190,63 +224,70 @@ $result_trees{'on_node_line'} = {
                 }
               ],
               'cmdname' => 'footnote',
-              'parent' => {},
-              'source_info' => {
-                'file_name' => '',
-                'line_nr' => 1,
-                'macro' => ''
-              }
+              'contents' => [],
+              'extra' => {
+                'invalid_nesting' => 1
+              },
+              'line_nr' => {},
+              'parent' => {}
             },
             {
               'parent' => {},
-              'text' => ' '
+              'text' => ' ',
+              'type' => 'spaces_at_end'
             },
             {
               'args' => [
                 {
                   'contents' => [
+                    {
+                      'extra' => {
+                        'command' => {}
+                      },
+                      'parent' => {},
+                      'text' => ' ',
+                      'type' => 'empty_spaces_after_command'
+                    },
                     {
                       'parent' => {},
                       'text' => 'exdent'
+                    },
+                    {
+                      'parent' => {},
+                      'text' => '
+',
+                      'type' => 'spaces_at_end'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'type' => 'misc_line_arg'
                 }
               ],
               'cmdname' => 'exdent',
               'extra' => {
-                'spaces_before_argument' => ' '
+                'invalid_nesting' => 1,
+                'misc_content' => [
+                  {}
+                ],
+                'spaces_after_command' => {}
               },
-              'parent' => {},
-              'source_info' => {
-                'file_name' => '',
-                'line_nr' => 1,
-                'macro' => ''
-              }
+              'line_nr' => {},
+              'parent' => {}
             }
           ],
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
           'parent' => {},
-          'type' => 'line_arg'
+          'type' => 'misc_line_arg'
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [
-              {}
-            ],
+            'node_content' => [],
             'normalized' => 'a'
           },
           {
@@ -259,65 +300,80 @@ $result_trees{'on_node_line'} = {
               {},
               {}
             ],
-            'normalized' => '-'
+            'normalized' => ''
           }
         ],
         'normalized' => 'a',
-        'spaces_before_argument' => ' '
+        'spaces_after_command' => {}
       },
-      'parent' => {},
-      'source_info' => {
-        'file_name' => '',
-        'line_nr' => 1,
-        'macro' => ''
-      }
+      'line_nr' => {},
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
 $result_trees{'on_node_line'}{'contents'}[0]{'parent'} = $result_trees{'on_node_line'};
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[1];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[2];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[3];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'on_node_line'}{'contents'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'extra'}{'node_argument'}{'manual_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[3];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'manual_content'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'node_content'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[3]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'extra'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'args'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'line_nr'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[6]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'extra'}{'misc_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'line_nr'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1];
 $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'on_node_line'}{'contents'}[1];
-$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'manual_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'manual_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[2];
 $result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[4];
 $result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[1] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[5];
 $result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[2] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[6];
 $result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[3] = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[1]{'contents'}[7];
+$result_trees{'on_node_line'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'on_node_line'}{'contents'}[1]{'line_nr'} = $result_trees{'on_node_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'on_node_line'}{'contents'}[1]{'parent'} = $result_trees{'on_node_line'};
 
 $result_texis{'on_node_line'} = '@node @ref{a, b, c, filename}, (@pxref{(somemanual)Top}) @anchor{in anchor}@footnote{footnote} @exdent exdent
@@ -326,30 +382,38 @@ $result_texis{'on_node_line'} = '@node @ref{a, b, c, filename}, (@pxref{(someman
 
 $result_texts{'on_node_line'} = '';
 
+$result_sectioning{'on_node_line'} = {};
+
 $result_nodes{'on_node_line'} = {
   'cmdname' => 'node',
   'extra' => {
     'normalized' => 'a'
   },
-  'structure' => {
-    'node_next' => {
-      'extra' => {
-        'manual_content' => [
-          {
-            'cmdname' => 'pxref',
-            'extra' => {
-              'node_argument' => {
-                'manual_content' => [
-                  {
-                    'text' => 'somemanual'
-                  }
-                ]
-              }
+  'node_next' => {
+    'extra' => {
+      'manual_content' => [
+        {
+          'cmdname' => 'pxref',
+          'extra' => {
+            'brace_command_contents' => [
+              [
+                {
+                  'text' => '(somemanual)Top'
+                }
+              ]
+            ],
+            'node_argument' => {
+              'manual_content' => [
+                {
+                  'text' => 'somemanual'
+                }
+              ],
+              'normalized' => 'Top'
             }
           }
-        ],
-        'normalized' => '-'
-      }
+        }
+      ],
+      'normalized' => ''
     }
   }
 };
@@ -358,13 +422,12 @@ $result_menus{'on_node_line'} = {
   'cmdname' => 'node',
   'extra' => {
     'normalized' => 'a'
-  },
-  'structure' => {}
+  }
 };
 
 $result_errors{'on_node_line'} = [
   {
-    'error_line' => 'warning: @ref should not appear in @node
+    'error_line' => ':1: warning: @ref should not appear in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -373,7 +436,7 @@ $result_errors{'on_node_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @pxref should not appear in @node
+    'error_line' => ':1: warning: @pxref should not appear in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -382,7 +445,7 @@ $result_errors{'on_node_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @anchor should not appear in @node
+    'error_line' => ':1: warning: @anchor should not appear in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -391,7 +454,7 @@ $result_errors{'on_node_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @footnote should not appear in @node
+    'error_line' => ':1: warning: @footnote should not appear in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -400,7 +463,7 @@ $result_errors{'on_node_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @exdent should only appear at the beginning of a line
+    'error_line' => ':1: warning: @exdent should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -409,7 +472,7 @@ $result_errors{'on_node_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @exdent should not appear in @node
+    'error_line' => ':1: warning: @exdent should not appear in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -420,7 +483,4 @@ $result_errors{'on_node_line'} = [
 ];
 
 
-$result_floats{'on_node_line'} = {};
-
-
 1;
