@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -13,45 +13,63 @@ $result_trees{'section_on_index_entry_line'} = {
           'args' => [
             {
               'contents' => [
+                {
+                  'extra' => {
+                    'command' => {}
+                  },
+                  'parent' => {},
+                  'text' => ' ',
+                  'type' => 'empty_spaces_after_command'
+                },
                 {
                   'parent' => {},
                   'text' => 'a '
                 }
               ],
               'parent' => {},
-              'type' => 'line_arg'
+              'type' => 'misc_line_arg'
             }
           ],
           'cmdname' => 'cindex',
           'extra' => {
-            'spaces_before_argument' => ' '
+            'spaces_after_command' => {}
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => ' ',
+              'type' => 'empty_spaces_after_command'
+            },
             {
               'parent' => {},
               'text' => 'b'
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'spaces_at_end'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
-'
-          },
           'parent' => {},
-          'type' => 'line_arg'
+          'type' => 'misc_line_arg'
         }
       ],
       'cmdname' => 'section',
@@ -75,27 +93,38 @@ $result_trees{'section_on_index_entry_line'} = {
         }
       ],
       'extra' => {
-        'spaces_before_argument' => ' '
+        'invalid_nesting' => 1,
+        'misc_content' => [
+          {}
+        ],
+        'spaces_after_command' => {}
       },
-      'parent' => {},
-      'source_info' => {
-        'file_name' => '',
-        'line_nr' => 1,
-        'macro' => ''
-      }
+      'level' => 2,
+      'line_nr' => {},
+      'number' => 1,
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
+$result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0];
 $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0];
+$result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0];
+$result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0];
 $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'};
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1];
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0];
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0];
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0];
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1];
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1];
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'contents'}[1];
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1];
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'section_on_index_entry_line'}{'contents'}[1]{'line_nr'} = $result_trees{'section_on_index_entry_line'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'section_on_index_entry_line'}{'contents'}[1]{'parent'} = $result_trees{'section_on_index_entry_line'};
 
 $result_texis{'section_on_index_entry_line'} = '@cindex a @section b
@@ -111,26 +140,22 @@ Somethin
 ';
 
 $result_sectioning{'section_on_index_entry_line'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 1,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => 1
-  }
+  'level' => 1,
+  'section_childs' => [
+    {
+      'cmdname' => 'section',
+      'extra' => {},
+      'level' => 2,
+      'number' => 1,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'section_on_index_entry_line'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'section_on_index_entry_line'};
+$result_sectioning{'section_on_index_entry_line'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'section_on_index_entry_line'};
 
 $result_errors{'section_on_index_entry_line'} = [
   {
-    'error_line' => 'warning: @section should only appear at the beginning of a line
+    'error_line' => ':1: warning: @section should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -139,7 +164,7 @@ $result_errors{'section_on_index_entry_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @section should not appear in @cindex
+    'error_line' => ':1: warning: @section should not appear in @cindex
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -150,7 +175,4 @@ $result_errors{'section_on_index_entry_line'} = [
 ];
 
 
-$result_floats{'section_on_index_entry_line'} = {};
-
-
 1;
