@@ -54,11 +54,7 @@ $result_trees{'anchor_in_titlepage_titlepage'} = {
                 'node_content' => [
                   {}
                 ],
-                'normalized' => 'in-titlepage',
-                'spaces_before_argument' => {
-                  'text' => '',
-                  'type' => 'empty_spaces_before_argument'
-                }
+                'normalized' => 'in-titlepage'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -68,6 +64,7 @@ $result_trees{'anchor_in_titlepage_titlepage'} = {
               'parent' => {}
             },
             {
+              'parent' => {},
               'text' => '
 ',
               'type' => 'empty_spaces_after_close_brace'
@@ -242,10 +239,6 @@ $result_trees{'anchor_in_titlepage_titlepage'} = {
                     {}
                   ],
                   'normalized' => 'in-titlepage'
-                },
-                'spaces_before_argument' => {
-                  'text' => '',
-                  'type' => 'empty_spaces_before_argument'
                 }
               },
               'line_nr' => {
@@ -297,6 +290,7 @@ $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'co
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
+$result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4];
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0];
 $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'anchor_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0];
