@@ -91,6 +91,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -160,6 +161,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -174,6 +176,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -249,6 +252,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -263,6 +267,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -277,6 +282,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -358,6 +364,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -372,6 +379,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -386,6 +394,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -550,6 +559,11 @@ $result_trees{'node'} = {
               ],
               'cmdname' => 'comma',
               'contents' => [],
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 10,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -563,6 +577,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -580,6 +595,8 @@ $result_trees{'node'} = {
                 }
               ],
               'cmdname' => ',',
+              'contents' => [],
+              'line_nr' => {},
               'parent' => {}
             },
             {
@@ -593,6 +610,7 @@ $result_trees{'node'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -611,11 +629,7 @@ $result_trees{'node'} = {
               ],
               'cmdname' => 'strong',
               'contents' => [],
-              'line_nr' => {
-                'file_name' => '',
-                'line_nr' => 10,
-                'macro' => ''
-              },
+              'line_nr' => {},
               'parent' => {}
             },
             {
@@ -697,6 +711,7 @@ $result_trees{'node'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command
 $result_trees{'node'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[2]{'args'}[0];
 $result_trees{'node'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[2]{'args'}[0];
 $result_trees{'node'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[2];
+$result_trees{'node'}{'contents'}[2]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[2]{'args'}[1];
 $result_trees{'node'}{'contents'}[2]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[2]{'args'}[1];
 $result_trees{'node'}{'contents'}[2]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[2]{'args'}[1];
 $result_trees{'node'}{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'node'}{'contents'}[2];
@@ -709,8 +724,10 @@ $result_trees{'node'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command
 $result_trees{'node'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[0];
 $result_trees{'node'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[0];
 $result_trees{'node'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[3];
+$result_trees{'node'}{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[1];
 $result_trees{'node'}{'contents'}[3]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[1];
 $result_trees{'node'}{'contents'}[3]{'args'}[1]{'parent'} = $result_trees{'node'}{'contents'}[3];
+$result_trees{'node'}{'contents'}[3]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[2];
 $result_trees{'node'}{'contents'}[3]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[2];
 $result_trees{'node'}{'contents'}[3]{'args'}[2]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[3]{'args'}[2];
 $result_trees{'node'}{'contents'}[3]{'args'}[2]{'parent'} = $result_trees{'node'}{'contents'}[3];
@@ -724,10 +741,13 @@ $result_trees{'node'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command
 $result_trees{'node'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[0];
 $result_trees{'node'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[0];
 $result_trees{'node'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[4];
+$result_trees{'node'}{'contents'}[4]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[1];
 $result_trees{'node'}{'contents'}[4]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[1];
 $result_trees{'node'}{'contents'}[4]{'args'}[1]{'parent'} = $result_trees{'node'}{'contents'}[4];
+$result_trees{'node'}{'contents'}[4]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[2];
 $result_trees{'node'}{'contents'}[4]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[2];
 $result_trees{'node'}{'contents'}[4]{'args'}[2]{'parent'} = $result_trees{'node'}{'contents'}[4];
+$result_trees{'node'}{'contents'}[4]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[3];
 $result_trees{'node'}{'contents'}[4]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[3];
 $result_trees{'node'}{'contents'}[4]{'args'}[3]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[4]{'args'}[3];
 $result_trees{'node'}{'contents'}[4]{'args'}[3]{'parent'} = $result_trees{'node'}{'contents'}[4];
@@ -742,10 +762,13 @@ $result_trees{'node'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command
 $result_trees{'node'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[0];
 $result_trees{'node'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[0];
 $result_trees{'node'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[5];
+$result_trees{'node'}{'contents'}[5]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[1];
 $result_trees{'node'}{'contents'}[5]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[1];
 $result_trees{'node'}{'contents'}[5]{'args'}[1]{'parent'} = $result_trees{'node'}{'contents'}[5];
+$result_trees{'node'}{'contents'}[5]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[2];
 $result_trees{'node'}{'contents'}[5]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[2];
 $result_trees{'node'}{'contents'}[5]{'args'}[2]{'parent'} = $result_trees{'node'}{'contents'}[5];
+$result_trees{'node'}{'contents'}[5]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[3];
 $result_trees{'node'}{'contents'}[5]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[3];
 $result_trees{'node'}{'contents'}[5]{'args'}[3]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[5]{'args'}[3];
 $result_trees{'node'}{'contents'}[5]{'args'}[3]{'parent'} = $result_trees{'node'}{'contents'}[5];
@@ -776,13 +799,17 @@ $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'args'}[0]{'paren
 $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[0];
 $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[0];
 $result_trees{'node'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7];
+$result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[1];
 $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1];
+$result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1]{'line_nr'} = $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[1];
 $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[1];
 $result_trees{'node'}{'contents'}[7]{'args'}[1]{'parent'} = $result_trees{'node'}{'contents'}[7];
+$result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2];
 $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'args'}[0];
 $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1];
+$result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'line_nr'} = $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2];
 $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[2]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2];
 $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[3];
@@ -796,7 +823,7 @@ $result_trees{'node'}{'contents'}[7]{'extra'}{'nodes_manuals'}[1]{'node_content'
 $result_trees{'node'}{'contents'}[7]{'extra'}{'nodes_manuals'}[1]{'node_content'}[1] = $result_trees{'node'}{'contents'}[7]{'args'}[1]{'contents'}[2];
 $result_trees{'node'}{'contents'}[7]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1];
 $result_trees{'node'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'node'}{'contents'}[7]{'line_nr'} = $result_trees{'node'}{'contents'}[7]{'args'}[2]{'contents'}[1]{'line_nr'};
+$result_trees{'node'}{'contents'}[7]{'line_nr'} = $result_trees{'node'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'node'}{'contents'}[7]{'parent'} = $result_trees{'node'};
 
 $result_texis{'node'} = '
