@@ -1,32 +1,33 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'top_no_argument_and_content'} = {
   'contents' => [
     {
-      'contents' => [
-        {
-          'contents' => [],
-          'parent' => {},
-          'type' => 'preamble_before_content'
-        }
-      ],
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
-          'extra' => {
-            'spaces_after_argument' => '
-'
-          },
+          'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            }
+          ],
           'parent' => {},
-          'type' => 'line_arg'
+          'type' => 'misc_line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -49,22 +50,29 @@ $result_trees{'top_no_argument_and_content'} = {
           'type' => 'paragraph'
         }
       ],
-      'parent' => {},
-      'source_info' => {
+      'extra' => {
+        'misc_content' => [],
+        'spaces_after_command' => {}
+      },
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'top_no_argument_and_content'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[0];
 $result_trees{'top_no_argument_and_content'}{'contents'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'};
+$result_trees{'top_no_argument_and_content'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1];
+$result_trees{'top_no_argument_and_content'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'args'}[0];
 $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1];
 $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1];
 $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'contents'}[1];
 $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1];
+$result_trees{'top_no_argument_and_content'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'top_no_argument_and_content'}{'contents'}[1]{'parent'} = $result_trees{'top_no_argument_and_content'};
 
 $result_texis{'top_no_argument_and_content'} = '@top
@@ -78,54 +86,73 @@ A.
 ';
 
 $result_sectioning{'top_no_argument_and_content'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'structure' => {
-          'section_level' => 0,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => -1
-  }
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {},
+      'level' => 0,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'top_no_argument_and_content'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'top_no_argument_and_content'};
+$result_sectioning{'top_no_argument_and_content'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'top_no_argument_and_content'};
 
 $result_errors{'top_no_argument_and_content'} = [];
 
 
-$result_floats{'top_no_argument_and_content'} = {};
-
-
 
 $result_converted{'plaintext'}->{'top_no_argument_and_content'} = 'A.
 ';
 
 
-$result_converted{'html'}->{'top_no_argument_and_content'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'top_no_argument_and_content'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <title>Untitled Document</title>
 
 <meta name="description" content="Untitled Document">
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta name="viewport" content="width=device-width,initial-scale=1">
-
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
+<style type="text/css">
+<!--
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
+blockquote.smallquotation {font-size: smaller}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+div.lisp {margin-left: 3.2em}
+div.smalldisplay {margin-left: 3.2em}
+div.smallexample {margin-left: 3.2em}
+div.smalllisp {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+pre.smalldisplay {font-family: inherit; font-size: smaller}
+pre.smallexample {font-size: smaller}
+pre.smallformat {font-family: inherit; font-size: smaller}
+pre.smalllisp {font-size: smaller}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+ul.no-bullet {list-style: none}
+-->
+</style>
 
 
 </head>
 
 <body lang="en">
-<div class="top-level-extent" id="SEC_Top">
+<a name="SEC_Top"></a>
 
 <p>A.
-</p></div>
+</p><hr>
 
 
 
