@@ -67,11 +67,7 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'rrr',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'rrr'
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -81,6 +77,7 @@ $result_trees{'flushright_in_example'} = {
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => ' ',
                   'type' => 'empty_spaces_after_close_brace'
                 },
@@ -117,11 +114,7 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'a1',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'a1'
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -131,6 +124,7 @@ $result_trees{'flushright_in_example'} = {
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => ' ',
                   'type' => 'empty_spaces_after_close_brace'
                 },
@@ -162,16 +156,13 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'a2',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'a2'
                   },
                   'line_nr' => {},
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => ' ',
                   'type' => 'empty_spaces_after_close_brace'
                 },
@@ -208,11 +199,7 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'a3',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'a3'
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -222,6 +209,7 @@ $result_trees{'flushright_in_example'} = {
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => ' ',
                   'type' => 'empty_spaces_after_close_brace'
                 },
@@ -253,16 +241,13 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'a4',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'a4'
                   },
                   'line_nr' => {},
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => ' ',
                   'type' => 'empty_spaces_after_close_brace'
                 },
@@ -317,11 +302,7 @@ $result_trees{'flushright_in_example'} = {
                     'node_content' => [
                       {}
                     ],
-                    'normalized' => 'alone',
-                    'spaces_before_argument' => {
-                      'text' => '',
-                      'type' => 'empty_spaces_before_argument'
-                    }
+                    'normalized' => 'alone'
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -331,6 +312,7 @@ $result_trees{'flushright_in_example'} = {
                   'parent' => {}
                 },
                 {
+                  'parent' => {},
                   'text' => '
 ',
                   'type' => 'empty_spaces_after_close_brace'
@@ -476,6 +458,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0];
@@ -483,6 +466,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'args'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8];
@@ -490,6 +474,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'line_nr'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[5]{'line_nr'};
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'args'}[0];
@@ -497,6 +482,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'args'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'args'}[0]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15];
@@ -504,6 +490,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'line_nr'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[12]{'line_nr'};
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[16]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[17]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[18]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[19]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
@@ -514,6 +501,7 @@ $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[22]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[22]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[22]{'extra'}{'node_content'}[0] = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[22]{'args'}[0]{'contents'}[0];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[22]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[23]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[24]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[25]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[26]{'parent'} = $result_trees{'flushright_in_example'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
